@@ -3,24 +3,68 @@
  Copyright (c) 2016 by Cisco Systems, Inc.
  All rights reserved.
  */
-app.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 'requestRoutingService', '$timeout',
+app.register.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 'requestRoutingService', '$timeout',
     function ($scope, $filter, gridCrudService, requestRoutingService, $timeout) {
         var translate = $filter("translate"), exportData = [], dateTimeStamp = "";
-
         $scope.headersInExport = [translate("clients_mac"), translate("clients_switchport"), translate("clients_name"),
             translate("clients_os"), translate("clients_manufacturer"),
             translate("clients_ip"), translate("clients_vlan"), translate("clients_poe")
         ];
         var showCDPDetails;
+        var showLldpDeatils;
+        format_attributes= function(showLldpDetails) { 
+             for(var i in showLldpDetails){
+                 if(showLldpDetails[i].Capabilities.indexOf("T") != -1){
+                    showLldpDetails[i].Capabilities="Phone";
+                 } else if(showLldpDetails[i].Capabilities.indexOf("B") != -1){
+                    showLldpDetails[i].Capabilities ="Trans-Bridge";
+                 } else if (showLldpDetails[i].Capabilities.indexOf("R") != -1){
+                    showLldpDetails[i].Capabilities = "Router";
+                 } else if(showLldpDetails[i].Capabilities.indexOf("W") != -1){
+                    showLldpDetails[i].Capabilities="Wireless";        
+                 }
+
+                 if(showLldpDetails[i].VLAN.indexOf("not advertised") != -1){
+                    showLldpDetails[i].VLAN = "NA";
+                 }
+             }
+           
+             return showLldpDetails;
+        }
+ 
+        
+        remove_duplicates = function(showCDPDetails, showLldpDetails) {
+            for (var i in showCDPDetails) {
+                 for (var j in showLldpDetails) {
+                      if(showLldpDetails[j].ClientName == showCDPDetails[i].ClientName){
+                         showLldpDetails.splice(j, 1);
+                         break;
+                      }
+                 }
+            }        
+            if (typeof showLldpDetails == "object") { 
+                showCDPDetails = showCDPDetails.concat(showLldpDetails);           
+            } 
+            return showCDPDetails;
+        }
+
         $scope.showCDP = function(){
             showCDPDetails = requestRoutingService.getShowCmdOutput("show cdp neighbors detail", "clientsShowCdpNeighborsDetail");
             showCDPDetails = showCDPDetails.showCdpNeighborsDetail.wnwebdata;
+            showLldpDetails = requestRoutingService.getShowCmdOutput("show lldp neighbors detail", "clientsShowLldpNeighborsDetail");
+            showLldpDetails = showLldpDetails.showLldpNeighborsDetail.wnwebdata;
+            showLldpDetails = format_attributes(showLldpDetails);
+            if(typeof showCDPDetails != "object") {                
+                showCDPDetails = showLldpDetails;
+            } else {
+               showCDPDetails =  remove_duplicates(showCDPDetails, showLldpDetails);
+            }
+          
             if (typeof showCDPDetails == "object" && !showCDPDetails.length){
                 showCDPDetails = [showCDPDetails];
             }
             showCDPDetails = $filter("filter")(showCDPDetails);
-            
-            var showDeviceClassifier =requestRoutingService.getShowCmdOutput("show device classifier attached", "clientsShowDeviceClassifierAttached");;
+            var showDeviceClassifier =requestRoutingService.getShowCmdOutput("show device classifier attached", "clientsShowDeviceClassifierAttached");
             if(showDeviceClassifier.showDeviceClassifierAttached.wnwebdata!='')
             {
                 showDeviceClassifier = showDeviceClassifier.showDeviceClassifierAttached.wnwebdata.entry;
@@ -35,13 +79,11 @@ app.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 're
                 if (!(showCDPDetails[i].VLAN)){
                     showCDPDetails[i].VLAN = "NA"
                 }
-
                 if (showCDPDetails[i].PoEDrawn){
                     showCDPDetails[i].PoEDrawn = ((parseFloat(showCDPDetails[i].PoEDrawn)).toFixed(2)) + "W";
                 }else{
                     showCDPDetails[i].PoEDrawn = "0W";
                 }
-               
                 if(showCDPDetails[i].Capabilities.indexOf("Trans-Bridge")!=-1 || showCDPDetails[i].Capabilities.indexOf("Switch")!=-1){
                 	 showCDPDetails[i].Images = "/resources/images/distribution_switch.png";
                 }else if(showCDPDetails[i].Capabilities.indexOf("Router")!=-1){
@@ -50,68 +92,67 @@ app.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 're
                 	showCDPDetails[i].Images = "/resources/images/phone.png";
                 }else if(showCDPDetails[i].Capabilities.indexOf("Apple")!=-1){
                 	showCDPDetails[i].Images = "/resources/images/apple-device.png";
+                }else if(showCDPDetails[i].Capabilities.indexOf("Wireless")!=-1){
+                       showCDPDetails[i].Images = "/resources/images/wireless_router.png";
                 }else{
                 	 showCDPDetails[i].Images = "/resources/images/unknown_device.png";
                 }
-               
                 var deviceInterface=null;
                 for (var j in showDeviceClassifier) {
-                	deviceInterface=showCDPDetails[i].SwitchPort
-                	if(deviceInterface.indexOf("TenGigabitEthernet")!=-1){
-                		deviceInterface=deviceInterface.replace("TenGigabitEthernet","Te")
-                	}else if(deviceInterface.indexOf("GigabitEthernet")!=-1){
-                		deviceInterface=deviceInterface.replace("GigabitEthernet","Gi")
-                	}else if(deviceInterface.indexOf("FastEthernet")!=-1){
-                		deviceInterface=deviceInterface.replace("FastEthernet","Fa")
-                	} 
-                    if (deviceInterface == showDeviceClassifier[j].SwitchPort && showCDPDetails[i].Manufacturer == showDeviceClassifier[j].Manufacturer){
-                        showCDPDetails[i].MAC = showDeviceClassifier[j].MAC;
-                    }
+					if (showDeviceClassifier.hasOwnProperty(j)) {
+						deviceInterface=showCDPDetails[i].SwitchPort
+						if(deviceInterface.indexOf("TenGigabitEthernet")!=-1){
+							deviceInterface=deviceInterface.replace("TenGigabitEthernet","Te")
+						}else if(deviceInterface.indexOf("GigabitEthernet")!=-1){
+							deviceInterface=deviceInterface.replace("GigabitEthernet","Gi")
+						}else if(deviceInterface.indexOf("FastEthernet")!=-1){
+							deviceInterface=deviceInterface.replace("FastEthernet","Fa")
+						}
+						if (deviceInterface == showDeviceClassifier[j].SwitchPort && showCDPDetails[i].Manufacturer == showDeviceClassifier[j].Manufacturer){
+							showCDPDetails[i].MAC = showDeviceClassifier[j].MAC;
+						}
+					}
                 }
             }
-            
             var appleClient = 0;
             if(showCDPDetails != undefined){
             	appleClient= showCDPDetails.length;
             } else {
             	showCDPDetails = [];
             }
-            var deviceInterface=null;
+            var deviceInterface1=null;
             for (var i in showDeviceClassifier) {
             	if(showDeviceClassifier[i].Manufacturer.indexOf("APPLE")!=-1){
             		showCDPDetails[appleClient]={};
 	            	showCDPDetails[appleClient].MAC = showDeviceClassifier[i].MAC;
-	            	deviceInterface=showDeviceClassifier[i].SwitchPort;
-                	if(deviceInterface.indexOf("Gi")!=-1){
-                		deviceInterface=deviceInterface.replace("Gi","GigabitEthernet")
-                	}else if(deviceInterface.indexOf("Fa")!=-1){
-                		deviceInterface=deviceInterface.replace("Fa","FastEthernet")
-                	}else if(deviceInterface.indexOf("Te")!=-1){
-                		deviceInterface=deviceInterface.replace("Te","TenGigabitEthernet")
+	            	deviceInterface1=showDeviceClassifier[i].SwitchPort;
+                	if(deviceInterface1.indexOf("Gi")!=-1){
+                		deviceInterface1=deviceInterface1.replace("Gi","GigabitEthernet")
+                	}else if(deviceInterface1.indexOf("Fa")!=-1){
+                		deviceInterface1=deviceInterface1.replace("Fa","FastEthernet")
+                	}else if(deviceInterface1.indexOf("Te")!=-1){
+                		deviceInterface1=deviceInterface1.replace("Te","TenGigabitEthernet")
                 	}
-	            	showCDPDetails[appleClient].SwitchPort = deviceInterface;
+	            	showCDPDetails[appleClient].SwitchPort = deviceInterface1;
 	            	showCDPDetails[appleClient].ClientName = showDeviceClassifier[i].ClientName;
 	            	showCDPDetails[appleClient].OS = "";
 	            	showCDPDetails[appleClient].Manufacturer = showDeviceClassifier[i].Manufacturer;
 	            	showCDPDetails[appleClient].IP = "";
 	            	showCDPDetails[appleClient].VLAN = "";
-	            	showCDPDetails[appleClient].PoEDrawn = "";            	
+	            	showCDPDetails[appleClient].PoEDrawn = "";
 	            	showCDPDetails[appleClient].Images = "/resources/images/apple-device.png";
 	            	appleClient++;
             	}
             }
         }
         $scope.showCDP();
-
         $scope.gridDataSource1 = new kendo.data.DataSource({
             pageSize: 10,
             data: showCDPDetails
         });
-
         $scope.getHeader = function () {
             return $scope.headersInExport;
         };
-
         $scope.getArray = function () {
             $scope.dataForExport = function () {
                     showCDPDetails.forEach(function (x) {
@@ -133,7 +174,6 @@ app.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 're
             exportData = [];
             return $scope.dataForExport;
         };
-
         $scope.portsGridOptions = {
             dataSource: $scope.gridDataSource1,
             editable: false,
@@ -157,10 +197,10 @@ app.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 're
             selectable: true,
             pageable: {
             	messages: {
-					  display: translate("com_page_display"), 
+					  display: translate("com_page_display"),
 					  empty: translate("com_page_empty"),
 					  page: translate("com_page_pagetext"),
-					  of:translate("com_page_of"),  
+					  of:translate("com_page_of"),
 					  itemsPerPage: translate("com_page_itemsPerPage"),
 					  first: translate("com_page_first"),
 					  previous: translate("com_page_previous"),
@@ -202,6 +242,7 @@ app.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 're
             }, {
                 field: "Images",
                 title: translate("clients_images"),
+                filterable :false,
                 template: "<img src='#= Images #' />"
         }]
         };
@@ -209,8 +250,7 @@ app.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 're
             angular.element("#clientGrid").find('.k-pager-refresh').click(function(){
                 $scope.manualGridRefresh();
             });
-        },10);
-        
+        },10);        
         // Manual refresh the kendo ui grid table
         $scope.manualGridRefresh = function() {
             $scope.showCDP();
@@ -224,6 +264,5 @@ app.controller('ClientsMonitoring', ['$scope', '$filter', 'gridCrudService', 're
             $scope.gridDataSource1.read();
             grid.refresh();
         }
-
     }
 ]);
