@@ -3,14 +3,13 @@
  Copyright (c) 2016 by Cisco Systems, Inc.
  All rights reserved.
  */
-app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gridCrudService','requestRoutingService','dataSourceService','dialogService','notificationService','executeCliCmdService','validationService','getStringLineService',
+app.register.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gridCrudService','requestRoutingService','dataSourceService','dialogService','notificationService','executeCliCmdService','validationService','getStringLineService',
 	function($scope,$rootScope,$timeout, $filter, gridCrudService,requestRoutingService,dataSourceService,dialogService,notificationService,executeCliCmdService,validationService,getStringLineService) {
 		var trimVal=$filter('trimValue');
 		var translate = $filter("translate");
 		var versionInfo = requestRoutingService.getShowCmdOutput("show version","overviewshVer");
         var deviceType = versionInfo.ShowVersion.name;
-        var samplerTotalLimit = 4;
-		// $scope Variables are declared using angular.extend method. 
+		// $scope Variables are declared using angular.extend method.
 		angular.extend($scope, {
 			netFlowTemplateDataSource: [{nftText: translate("nft_application"), nftValue:'defaultApplicationTraffic', nftShort:'dat'},
                         {nftText: translate("nft_serverUtil"), nftValue:'defaultServerUtilization', nftShort:'dsu'},
@@ -39,7 +38,7 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
 		});
 
 		// Find the current Device
-		if(deviceType.indexOf("2960X") != -1 || deviceType.indexOf("2960XR") != -1){
+		if(deviceType.indexOf("2960X") != -1 || deviceType.indexOf("2960XR") != -1 || deviceType.indexOf("3560CX") != -1){
 			var fullNetFlow = {samplingMethodText: translate("nf_sampling_fullnetflow"), samplingMethodValue:'fullnetflow'};
 			$scope.samplingMethodDataSource.push(fullNetFlow);
 			$scope.fullNetFlowSupport = true;
@@ -71,7 +70,7 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
 							var min= trimVal(input.prop('min'));
 							var max= trimVal(input.prop('max'));
 							var arr = input.val().replace('-',',');
-							arr= arr.split(',');						
+							arr= arr.split(',');
 							for(var i=0;i<arr.length;i++){
 								if(parseFloat(trimVal(arr[i]))>=min && parseFloat(trimVal(arr[i]))<=max) {
 									count++;
@@ -82,7 +81,9 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
 							}
 							return true;
 						}
-						else return true;
+						else {
+                            return true;
+                        }
 					}else{
 						return true;
 					}
@@ -96,21 +97,20 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
         	var splitDotFromIpAdd = ipAddress.split('.'), result = "";
         	for(var i = 0; i < splitDotFromIpAdd.length; i++){
         		if(Number(splitDotFromIpAdd[i]) < 15){
-        			result += "0";	
+        			result += "0";
         		}
         			result += parseInt(splitDotFromIpAdd[i]).toString(16);
         	}
         	return result;
         }
         $scope.netFlowMonitorsGridOptions = {
-            filterable: true,
             sortable: true,
             pageable: {
             	messages: {
-					  display: translate("com_page_display"), 
+					  display: translate("com_page_display"),
 					  empty: translate("com_page_empty"),
 					  page: translate("com_page_pagetext"),
-					  of:translate("com_page_of"),  
+					  of:translate("com_page_of"),
 					  itemsPerPage: translate("com_page_itemsPerPage"),
 					  first: translate("com_page_first"),
 					  previous: translate("com_page_previous"),
@@ -147,7 +147,6 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
                 },
                 {
                     field: "SamplerInterFaces",
-                    sortable: false,
 		            title: translate("nf_interface")
                 },
                 {
@@ -171,7 +170,7 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
         $scope.loadGridData = function () {
 	        $scope.netFlowMonitorsGridData = new kendo.data.ObservableArray([]);
 	        //show flow monitor
-	        var samplingStrCLIOutput="", showFlowInterface = "";
+	        var showFlowInterface = "";
 	        var strCLIOutput = deviceCommunicator.getExecCmdOutput("show flow monitor");
 	        var START_FLOW_MONITOR = ["Flow Monitor "];
 	        var START_FLOW_RECORD = ["Flow Record:"];
@@ -179,32 +178,21 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
 	        var END_FLOW_MONITOR = [":"];
 	        var END_OUTPUT = ["\n"];
 	        var arrFlowMonitor=strCLIOutput.split("Flow Monitor");
-            samplingStrCLIOutput = deviceCommunicator.getExecCmdOutput("show sampler\n");
             showFlowInterface = deviceCommunicator.getExecCmdOutput("show flow interface\n");
             var showFlowIntSamplers = getStringLineService.getLines(showFlowInterface,['traffic(ip): ']);
 	    var ipv6Samplers = getStringLineService.getLines(showFlowInterface,['traffic(ipv6): ']);
             showFlowIntSamplers = showFlowIntSamplers.concat(ipv6Samplers);
             var showFlowIntMonitors = getStringLineService.getLines(showFlowInterface,['monitor: ']);
-	        var LINE_INDEX = ["flow monitor"];
-            var samplingNameStrLines = getStringLineService.getLines(samplingStrCLIOutput,['Sampler ']);
-	        var samplingTypeStrLines = getStringLineService.getLines(samplingStrCLIOutput,['Type: ']);
             var netFlowMonitorObj = {};
-            var sampler = [];
             var showRunConfigInterface = [];
             $scope.showFlowIntRecords = [];
             //Associated Interface values
             var intStrCLIOutput = deviceCommunicator.getExecCmdOutput("show running-config | section interface");
-            var showRunConfigSecInterface = intStrCLIOutput.split("interface ");
-            var showRunConfigSecInterfaceRecord;
-            var START_FLOW_IPFLOW = ["monitor "];
-            var END_FLOW_INTERFACE = [" input"];
-            
+            var showRunConfigSecInterface = intStrCLIOutput.split("interface ");            
             for(var inter = 1; inter < showRunConfigSecInterface.length; inter++){
                 if(showRunConfigSecInterface[inter].indexOf("ip flow monitor")!=-1){
-                    var interfaceAssociateMonitorSampler = showRunConfigSecInterface[inter].split("ip flow ");
                     showRunConfigInterface.push(showRunConfigSecInterface[inter]);
                 } else if(showRunConfigSecInterface[inter].indexOf("ipv6 flow monitor")!=-1){
-                    var interfaceAssociateMonitorSampler = showRunConfigSecInterface[inter].split("ipv6 flow ");
                     showRunConfigInterface.push(showRunConfigSecInterface[inter]);
                 }
             }
@@ -216,11 +204,9 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
 	         		flowMonitorName = flowMonitorName.trim();
 	         	var flowRecord = executeCliCmdService.getNextString(flowMonitor,START_FLOW_RECORD,END_OUTPUT);
 	         		flowRecord = flowRecord.trim();
-                var flowExporter = executeCliCmdService.getNextString(flowMonitor,START_FLOW_EXPORTER,END_OUTPUT);	
+                var flowExporter = executeCliCmdService.getNextString(flowMonitor,START_FLOW_EXPORTER,END_OUTPUT);
                 if(flowExporter !== ""){
-                    var flowExporterValue = flowExporter.trim().replace(/ *\([^)]*\) */g, "");
-                    var tempSamplerName = flowMonitorName.substring($scope.monitorUnitName.length);
-                    
+                    var flowExporterValue = flowExporter.trim().replace(/ *\([^)]*\) */g, "");  
                     for(var shwInt = 0; shwInt < showFlowIntSamplers.length; shwInt++){
 			var showFlowIntSamplerNames = "";
                     	if(showFlowIntSamplers[shwInt].indexOf("traffic(ipv6):") != -1){
@@ -245,25 +231,26 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
                     }
              		var netFlowTemplateTemp = $filter('filter')($scope.netFlowTemplateDataSource, {"nftValue":flowRecord})
              			,showFlowExporter = requestRoutingService.getShowCmdOutput("show flow exporter "+flowExporterValue, "showFlowExporter")
-            			,shortNameOfNFTemplate = $filter('filter')($scope.netFlowTemplateDataSource, {"nftValue":flowRecord});
-                		
+            			,shortNameOfNFTemplate = $filter('filter')($scope.netFlowTemplateDataSource, {"nftValue":flowRecord});                		
                     if(showFlowExporter.showexporter.collectorIpAddress){
                         netFlowMonitorObj.Collector = showFlowExporter.showexporter.collectorIpAddress;
                     }
-        			netFlowMonitorObj.NetflowTemplate =  netFlowTemplateTemp[0].nftText;
+                    if(netFlowTemplateTemp.length > 0){
+        			    netFlowMonitorObj.NetflowTemplate =  netFlowTemplateTemp[0].nftText;
+                    }
 	        		netFlowMonitorObj.FlowRecord = flowRecord;
 	        		netFlowMonitorObj.FlowExporter = flowExporterValue;
 	        		netFlowMonitorObj.FlowMonitorName = flowMonitorName;
 	        		netFlowMonitorObj.Interface = showFlowExporter.showexporter.interface;
 	        		netFlowMonitorObj.Switch = showFlowExporter.showexporter.switchIpAddress;
-	        		if(showRunConfigInterface.length > 0){
-                        for(var inter = 0; inter < showRunConfigInterface.length; inter++){
-                            if(showRunConfigInterface[inter].indexOf(netFlowMonitorObj.FlowMonitorName) !== -1){
-				var interfaceMonSampIntName = "";
-                                if(showRunConfigInterface[inter].indexOf("ip flow monitor") != -1){
-                                	interfaceMonSampIntName = showRunConfigInterface[inter].split("ip flow monitor ");
+                    if(showRunConfigInterface.length > 0){
+                        for(var cInter = 0; cInter < showRunConfigInterface.length; cInter++){
+                            if(showRunConfigInterface[cInter].indexOf(netFlowMonitorObj.FlowMonitorName) !== -1){
+                                var interfaceMonSampIntName = "";
+                                if(showRunConfigInterface[cInter].indexOf("ip flow monitor") != -1){
+                                	interfaceMonSampIntName = showRunConfigInterface[cInter].split("ip flow monitor ");
                                 } else {
-                                 	interfaceMonSampIntName = showRunConfigInterface[inter].split("ipv6 flow monitor ");
+                                 	interfaceMonSampIntName = showRunConfigInterface[cInter].split("ipv6 flow monitor ");
                                 }
                                 var intNames = interfaceMonSampIntName[0].trim();
                                 var intExtraHasNames = intNames.split(" ");
@@ -271,16 +258,16 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
                                     intNames = intExtraHasNames[0];
                                 }
                                 netFlowMonitorObj.SamplerInterFaces = intNames;
-                                break;
+                                //break;
                             }else{
                                 netFlowMonitorObj.SamplerInterFaces = "";
                             }
-                        }
-                        if(netFlowMonitorObj.SamplerInterFaces !== ""){
-                            $scope.netFlowMonitorsGridData.push(netFlowMonitorObj);          
+                            if(netFlowMonitorObj.SamplerInterFaces !== ""){
+                                $scope.netFlowMonitorsGridData.push(netFlowMonitorObj);
+                            }
                         }
                     }
-                }  
+                }
             }
 	        $scope.netFlowMonitorsGridDataSource = new kendo.data.DataSource({
 				pageSize: 10,
@@ -356,12 +343,12 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
 			$scope.confirmationNetFlow('delete');
 		};
         $scope.confirmationNetFlow = function() {
-        	var interface=[];
-        	angular.forEach($scope.selectedNetFlowMonitorsArray, function(val,indX){
-        		interface.push(val.SamplerInterFaces);
+        	var inter=[];
+        	angular.forEach($scope.selectedNetFlowMonitorsArray, function(val){
+        		inter.push(val.SamplerInterFaces);
         	});
 			$scope.dlgNetFlow = dialogService.dialog({
-				content : translate("nf_msg_delete_confirmation")+"<br/>"+interface,
+				content : translate("nf_msg_delete_confirmation")+"<br/>"+inter,
 				title : translate("msg_delete_confirmation_window"),
 				messageType : "confirm",
 				actionButtons : [{
@@ -372,37 +359,37 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
 				}]
 			});
 		};
-		$scope.$on("netFlowDeleteConfirmation", function(event, data) {
+		$scope.$on("netFlowDeleteConfirmation", function() {
 			$scope.deleteBtnFunction($scope.dlgNetFlow.data("kendoWindow"));
 		});
         $scope.netFlowInit = function(){
         	var showInterfaces = requestRoutingService.getShowCmdOutput("show ip int brief", "showInterfaces");
         		showInterfaces = showInterfaces.showIpInterfaceBrief.IntBriefTable.entry;
-                angular.forEach(showInterfaces, function(interface, index){
-                    if(interface.interfaceName.indexOf("TenGigabitEthernet")!=-1){
-                        interface.interfaceName = interface.interfaceName.replace("TenGigabitEthernet","Te");
-                    }else if(interface.interfaceName.indexOf("FastEthernet")!=-1){
-                        interface.interfaceName = interface.interfaceName.replace("FastEthernet","Fa");
-                    }else if(interface.interfaceName.indexOf("GigabitEthernet")!=-1){
-                        interface.interfaceName = interface.interfaceName.replace("GigabitEthernet","Gi");
+                angular.forEach(showInterfaces, function(inter){
+                    if(inter.interfaceName.indexOf("TenGigabitEthernet")!=-1){
+                        inter.interfaceName = inter.interfaceName.replace("TenGigabitEthernet","Te");
+                    }else if(inter.interfaceName.indexOf("FastEthernet")!=-1){
+                        inter.interfaceName = inter.interfaceName.replace("FastEthernet","Fa");
+                    }else if(inter.interfaceName.indexOf("GigabitEthernet")!=-1){
+                        inter.interfaceName = inter.interfaceName.replace("GigabitEthernet","Gi");
                     }
-                    if(interface.ipAddress != 'unassigned'){
+                    if(inter.ipAddress != 'unassigned'){
         				var switchExportAddress = {
-	        				"text": interface.interfaceName+"_"+interface.ipAddress,
-	        				"ipAddress":interface.ipAddress,
-	        				"name":interface.interfaceName
+	        				"text": inter.interfaceName+"_"+inter.ipAddress,
+	        				"ipAddress":inter.ipAddress,
+	        				"name":inter.interfaceName
 	        			};
-                        $scope.switchExportAddress.push(switchExportAddress);        			
+                        $scope.switchExportAddress.push(switchExportAddress);
         			}
-                    $scope.inputCaptureInterface.push(interface);
+                    $scope.inputCaptureInterface.push(inter);
         		});
-        		var min = 32, max = 1032; 
+        		var min = 32, max = 1032;
         	for (var i = min; i <= max; i++) {
         		$scope.samplerMethodRange.push(""+i);
 		    }
-		    $scope.loadGridData();	
+		    $scope.loadGridData();
         }
-        //Initial load function for this controller 
+        //Initial load function for this controller
         $scope.netFlowInit();
 
         $scope.fnCancel = function(){
@@ -420,8 +407,7 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
             grid.dataSource = $scope.netFlowMonitorsGridDataSource;
             $scope.netFlowMonitorsGridDataSource.read();
             grid.refresh();
-        }
-        
+        }        
         $scope.findCLICMDIsAlreadyExists = function(recordName, CLICommand){
             var recordCLI = deviceCommunicator.getExecCmdOutput(CLICommand);
             if(recordCLI.indexOf(recordName) !== -1){
@@ -443,14 +429,14 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
         $scope.createNetFlow = function(){
             $scope.samplingMethodRangeType = angular.element("#samplerRangeContainer input").val();
             var flowRecordIsOneTime = $scope.findNetFlowTemplateIsAlreadyExists($scope.netFlowTemplateType);
-            var showFlowExporter = deviceCommunicator.getExecCmdOutput("show running-config | section interface");
             var exporterIsOneTime = $scope.findCLICMDIsAlreadyExists("export_"+$scope.switchExportAddType.split("/").join("_")+"_"+$scope.collectorIpAddress, "show flow exporter\n");
             var samplerIsOneTime = $scope.findCLICMDIsAlreadyExists("Sampler "+$scope.samplingMethodType+"_1_"+$scope.samplingMethodRangeType, "show sampler\n");
+            var interfaceIsOneTime;
             if(netFlowFormValidations.validate()){
         		if($scope.netFlowMonitorsGrid._data.length > 0){
-                    var interfaceIsOneTime = $filter('filter')($scope.netFlowMonitorsGrid._data, {"SamplerInterFaces":$scope.inputCapIntType});
+                    interfaceIsOneTime = $filter('filter')($scope.netFlowMonitorsGrid._data, {"SamplerInterFaces":$scope.inputCapIntType});
         		}else{
-        			var interfaceIsOneTime = [];
+        			interfaceIsOneTime = [];
         		}
         		if(interfaceIsOneTime.length == 0){
 	        		var netFlowConfigCLI = '';
@@ -529,13 +515,11 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
 		        		netFlowConfigCLI += "collect timestamp sys-uptime first \n";
 		        		netFlowConfigCLI += "collect timestamp sys-uptime last \n";
 		        		netFlowConfigCLI +=  "exit \n";
-		        	}
-		        	
+		        	}		        	
 		        	var source_interface = $filter('filter')($scope.switchExportAddress, {"text":$scope.switchExportAddType})
 		        		,shortNameOfNFTemplate = $filter('filter')($scope.netFlowTemplateDataSource, {"nftValue":$scope.netFlowTemplateType})
 		        		,switchExportAddressToHex = $scope.convertIpAddressToHex(source_interface[0].ipAddress.toString())
 		        		,collectoIpAddressToHex = $scope.convertIpAddressToHex($scope.collectorIpAddress.toString());
-		        	
 		        	// CLI command for Exporter (Switch Export IP address)
                     if(!exporterIsOneTime){
     		        	netFlowConfigCLI += "flow exporter export_"+$scope.switchExportAddType.split("/").join("_")+"_"+$scope.collectorIpAddress+" \n";
@@ -543,24 +527,20 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
     		        	netFlowConfigCLI += "source "+source_interface[0].name+" \n";
     		        	netFlowConfigCLI +=  "transport udp 2055 \n";
     		        	netFlowConfigCLI +=  "exit \n";
-                    }
-		        	
+                    }		        	
 		        	// CLI command for Sampling (Sampling Method)
                     if($scope.samplingMethodType !== "fullnetflow" && !samplerIsOneTime){
-                        //netFlowConfigCLI += "sampler "+shortNameOfNFTemplate[0].nftShort+"X"+source_interface[0].name+"_"+switchExportAddressToHex+"_"+collectoIpAddressToHex+" \n";
                         netFlowConfigCLI += "sampler "+$scope.samplingMethodType+"_1_"+$scope.samplingMethodRangeType+" \n";
     		        	netFlowConfigCLI += "mode "+$scope.samplingMethodType+" 1 out-of "+$scope.samplingMethodRangeType+" \n";
     		        	netFlowConfigCLI +=  "exit \n";
-                    }
-		        	
+                    }		        	
 		        	//CLI command for Create a flow monitor
 		        	netFlowConfigCLI += "flow monitor "+$scope.monitorUnitName+shortNameOfNFTemplate[0].nftShort+"X"+source_interface[0].name.split("/").join("_")+"_"+switchExportAddressToHex+"_"+collectoIpAddressToHex+$scope.inputCapIntType.replace(/\//g,"_")+" \n";
 		        	netFlowConfigCLI += "exporter export_"+$scope.switchExportAddType.split("/").join("_")+"_"+$scope.collectorIpAddress+" \n";
 		        	netFlowConfigCLI += "record "+$scope.netFlowTemplateType+" \n";
-		        	netFlowConfigCLI += "exit \n";
-			        
-                    //CLI command for Associate to an interface	
-		    var ipType = ($scope.netFlowTemplateType.indexOf("CapacityPlanning")!=-1)?"ipv6":"ip"; 
+		        	netFlowConfigCLI += "exit \n";			        
+                    //CLI command for Associate to an interface
+		    var ipType = ($scope.netFlowTemplateType.indexOf("CapacityPlanning")!=-1)?"ipv6":"ip";
                     if($scope.samplingMethodType !== "fullnetflow"){
                         netFlowConfigCLI += "interface "+$scope.inputCapIntType+" \n";
     			        netFlowConfigCLI += ipType + " flow monitor "+$scope.monitorUnitName+shortNameOfNFTemplate[0].nftShort+"X"+source_interface[0].name.split("/").join("_")+"_"+switchExportAddressToHex+"_"+collectoIpAddressToHex+$scope.inputCapIntType.replace(/\//g,"_")+" sampler "+$scope.samplingMethodType+"_1_"+$scope.samplingMethodRangeType+" input \n";
@@ -590,7 +570,7 @@ app.controller('netFlowCtrl', ['$scope','$rootScope','$timeout', '$filter', 'gri
                     if(interfaceIsOneTime.length > 0){
     	        		notificationService.showNotification(translate('nf_interface_warning_msg'),translate('nf_config_warning_title'),'error');
                     }
-	        	}	
+	        	}
         	}
         }
 	}]);
